@@ -148,7 +148,7 @@ class OptionGroupMixin:
             default_group.options = ungrouped_options
             records_by_group[default_group] = default_group.get_help_records(ctx)
 
-        if self.align_option_groups:
+        if self.align_option_groups and len(records_by_group) > 1:
             option_name_width = min(
                 max_option_width,
                 max(len(rec[0])
@@ -173,7 +173,7 @@ def option(
     group: Optional[OptionGroup] = None,
     cls: Type[click.Option] = GroupedOption,
     **attrs
-) -> OptionDecorator:
+) -> OptionGroupDecorator:
     def decorator(f):
         func = click.option(*param_decls, cls=cls, **attrs)(f)
         new_option = func.__click_params__[-1]
@@ -203,7 +203,7 @@ def option_group(
     ...  # pragma: no cover
 
 
-def option_group(name: str, *args, **kwargs) -> OptionDecorator:
+def option_group(name, *args, **kwargs):
     """
     Attaches an option group to the command. This decorator is overloaded with
     two signatures::
@@ -244,10 +244,9 @@ def _option_group(
             # and @cloup.option currently return the same f
             f = opt_decorator(f)
             new_option = f.__click_params__[-1]
-            curr_group = get_option_group_of(new_option)
-            if curr_group is not None:
+            if has_option_group(new_option):
                 raise ValueError(
-                    f'{new_option} was first assigned to {curr_group} and then '
+                    f'{new_option} was first assigned to {new_option.group} and then '
                     f'passed as argument to @option_group({name!r}, ...)'
                 )
             new_option.group = opt_group
